@@ -1,3 +1,3 @@
-from .errors import DuplicateSubscriptionError, FunctionCallNotAllowedError, \
+from .errors import DuplicateSubscriptionError, FunctionCallNotAllowedError, InvalidFileValue, \
     ModelNotProperlyInitialized, ReferenceFolderMissingError, SubscriptionAlreadyCanceledError
 from .handler import set_exception_handler
